@@ -53,6 +53,7 @@ class FabricOperatorTest(unittest.TestCase):
         self.assertTrue(op.execute(context={}))
 
         res = op.execute_fabric_command()
+        res.conn.open.assert_called()
         res.conn.run.assert_called_with(command=command, pty=pty, env=env, watchers=[], warn=True)
 
     def test_fabric_operator_use_sudo(self):
@@ -66,6 +67,7 @@ class FabricOperatorTest(unittest.TestCase):
                             use_sudo=True)
 
         res = op.execute_fabric_command()
+        res.conn.open.assert_called()
         res.conn.sudo.assert_called_with(command=command, pty=pty, env=env, watchers=[], warn=True,
                                          password=self.hook.password)
 
@@ -81,9 +83,45 @@ class FabricOperatorTest(unittest.TestCase):
                             use_sudo=True, sudo_user=sudo_user)
 
         res = op.execute_fabric_command()
+        res.conn.open.assert_called()
         res.conn.sudo.assert_called_with(command=command, pty=pty, env=env, watchers=[], warn=True,
                                          password=self.hook.password, user=sudo_user)
 
+    def test_fabric_operator_use_sudo_shell(self):
+        """
+        Test that parameter use_sudo_shell wraps the command in a sudo shell
+        """
+        command = faker.text()
+        env = faker.pydict()
+        pty = faker.pybool()
+        op = FabricOperator(task_id=TEST_TASK_ID, fabric_hook=self.hook, command=command, environment=env, get_pty=pty,
+                            use_sudo_shell=True)
+
+        res = op.execute_fabric_command()
+
+        expected_command = f"sudo -s -- <<'__end_of_sudo_shell__'\n{command}\n__end_of_sudo_shell__"
+
+        res.conn.open.assert_called()
+        res.conn.run.assert_called_with(command=expected_command, pty=pty, env=env, watchers=[], warn=True)
+
+    def test_fabric_operator_use_sudo_shell_with_user(self):
+        """
+        Test that parameter use_sudo_shell wraps the command in a sudo shell for the specified user
+        """
+        command = faker.text()
+        env = faker.pydict()
+        pty = faker.pybool()
+        sudo_user = faker.user_name()
+        op = FabricOperator(task_id=TEST_TASK_ID, fabric_hook=self.hook, command=command, environment=env, get_pty=pty,
+                            use_sudo_shell=True, sudo_user=sudo_user)
+
+        res = op.execute_fabric_command()
+
+        expected_command = f"sudo -su {sudo_user} -- <<'__end_of_sudo_shell__'\n{command}\n__end_of_sudo_shell__"
+
+        res.conn.open.assert_called()
+        res.conn.run.assert_called_with(command=expected_command, pty=pty, env=env, watchers=[], warn=True)
+
     def test_fabric_operator_execute_non_zero_exit(self):
         """
         Test that execution with a non-zero exit code fails and the exit code is logged
@@ -175,3 +213,13 @@ class FabricOperatorTest(unittest.TestCase):
 
         res = op.execute_fabric_command()
         self.assertEqual(res.stdout, self.hook.stdout.strip())
+
+    def test_set_keepalive_called(self):
+        """
+        Test that set_keepalive() is called on the client transport object with the specified value
+        """
+        op = FabricOperator(task_id=TEST_TASK_ID, fabric_hook=self.hook, command="ls", keepalive=60)
+        res = op.execute_fabric_command()
+
+        res.conn.open.assert_called()
+        res.conn.transport.set_keepalive.assert_called_with(60)
